package Bundle::HTMLWikiConverter;

$VERSION = '0.02';

1;

__END__

=head1 NAME

Bundle::HTMLWikiConverter - A bundle to install HTML::WikiConverter and all its dialects

=head1 SYNOPSIS

 perl -MCPAN -e 'install Bundle::HTMLWikiConverter'

=head1 CONTENTS

HTML::WikiConverter 0.51

HTML::WikiConverter::DokuWiki

HTML::WikiConverter::Kwiki

HTML::WikiConverter::MediaWiki

HTML::WikiConverter::MoinMoin

HTML::WikiConverter::Oddmuse

HTML::WikiConverter::PhpWiki

HTML::WikiConverter::PmWiki

HTML::WikiConverter::SnipSnap

HTML::WikiConverter::TikiWiki

HTML::WikiConverter::UseMod

HTML::WikiConverter::WakkaWiki

HTML::WikiConverter::WikkaWiki

=head1 DESCRIPTION

This bundle includes the L<HTML::WikiConverter> distribution as well
as all available dialect modules needed to convert HTML into a variety
of wiki markups.

=head1 ACKNOWLEDGEMENTS

Thanks to Tatsuhiko Miyagawa for suggesting that I create this bundle.

=head1 AUTHOR

David J. Iberri, E<lt>diberri at cpan.orgE<gt>

=head1 SEE ALSO

L<HTML::WikiConverter>

=cut
